#ifndef FROG_H
#define FROG_H

  
#include <sys/termios.h>
#include <fcntl.h>
#include <unistd.h>
#include <stdio.h>
#include <sys/ioctl.h>   
#include <string.h>
#include <math.h>
#include <time.h>
#include <stdlib.h>
#include <sys/file.h>


#define DEBUG 1

#define TRUE 1
#define FALSE 0

#define FROG_PROG_VERSION "0.4"

#define FROG_SPEED  B300
#define FROG_STOPBIT  2
#define FROG_RESET_DELAY 1
#define FROG_MAX_FRAME_SIZE 100
#define FROG_MAX_CHECKSUM_SIZE 5
#define FROG_DEVICE "/dev/ttyS0"
#define FROG_LOG FALSE
#define FROG_LOGFILE "/tmp/frog.log"
#define FROG_ALTITUDE 0
#define FROG_MIN_PERIOD 62
#define FROG_PERIOD 70
#define FROG_DEBUG FALSE
#define FROG_VERBOSE FALSE
#define FROG_DAEMON TRUE 
#define FROG_READ_DELAY 10
#define FROG_NB_RETRY -1
#define FROG_LOGTYPE "w"
 
#define MAX_SENSOR_DATA 200
#define MAX_SENSOR_NUMBER 3

#define SENSOR_MAX_NAME_SIZE 30
#define SENSOR_MAX_VALUE_NUMBER 3
#define SENSOR_IDENTIFICATION_MASK 0xF0
#define SENSOR_PRES_TEMP 0x10
#define SENSOR_HR  0x30

typedef struct  {   
   unsigned char identification;
   char name[SENSOR_MAX_NAME_SIZE];
} SensorType;

typedef struct  {   
   unsigned int identification;
   unsigned int phymesurementsize;
   unsigned int datasize;
   unsigned char data[MAX_SENSOR_DATA];
} Sensor;

  
typedef struct  {   
// config
   int debug;
   int verbose;
   int baud;
   int stopbit;
   int altitude;
   int period;
   char device[100];
   int log;
   char logfile[100];
   int daemon;
   int nbretry;
   char logtype[100];
// identification
   unsigned int firmware;
   unsigned int partnumber;
   unsigned int serialnumber;
   unsigned int nbsensor;   
// data
   int fd;
   Sensor sensor[MAX_SENSOR_NUMBER];
   float lasttemp;
   float lastpress;   
   float lasthum;
} Frog;

int InitFrog(Frog* frog);
char parse_cmdline(int argc,char *argv[], Frog* frog);

#endif
